Package io.github.og4dev.config


package io.github.og4dev.config
Configuration classes for the OG4Dev Spring API Response Library.

This package contains Spring Boot auto-configuration classes that automatically register required beans when the library is added to the classpath. Zero manual configuration is required - simply add the dependency and all features are enabled.

The ApiResponseAutoConfiguration class is automatically loaded by Spring Boot's autoconfiguration mechanism via META-INF/spring/org.springframework.boot.autoconfigure.AutoConfiguration.imports.

Since:
1.0.0
Version:
1.0.0
Author:
Pasindu OG